function cellArray = makeCellArray(dirNames)
% cellArray = makeCellArray(dirNames)
% converts the input into a cell array of strings
% dirNames can be: 
%  a cell array (no action taken)
%  a character array (each row is placed in its own cell and white space
%                     trimmed)
%  an array of structs, such as that returned by dir. (the "name" field
%              of each struct is placed in its own cell)
if iscell(dirNames)
    cellArray=dirNames;
    if size(cellArray,1) == 1 && size(cellArray,2) > 1
        cellArray = cellArray';
    end
    return;
end

cellArray = cell(size(dirNames,1),1);

if isstruct(dirNames) %as what is generated by the Matlab dir call
    if ~isfield(dirNames(1), 'name')
        error('Set of directory names is an array of structs, but the structs do not contain the field "name."');
    end
    for i=1:size(dirNames,1)
        cellArray{i}=strtrim(dirNames(i).name);
    end
elseif ischar(dirNames)
    for i=1:size(dirNames,1)
        cellArray{i}=strtrim(dirNames(i,:));
    end
else
    error('Set of directory names is not a recognized type (either char or struct)');
end
end
